.. meta::
   :description: Gaitalytics Normalisation.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, references

Normalisation
=============


.. automodule:: gaitalytics.normalisation
    :members:
    :special-members: __init__
